<?php
namespace MageDeveloper\Magepdf\Domain\Model;

require_once(\TYPO3\CMS\Core\Utility\ExtensionManagementUtility::extPath('magepdf') . 'Resources/Private/Libraries/dompdf/autoload.inc.php');

class Dompdf extends AbstractModel
{
	/**
	 * @var \Dompdf\Dompdf
	 */
	protected $dompdf;

	/**
	 * Constructor
	 * 
	 * @return Dompdf
	 */
	public function __construct()
	{
		$this->dompdf = new \Dompdf\Dompdf();
	}

	/**
	 * Gets the dompdf model
	 * 
	 * @return \DOMPDF
	 */
	public function getDompdf()
	{
		return $this->getData("dompdf");
	}
	
	/**
	 * Sets the paper size of the pdf document
	 * 
	 * @param string $size Paper Size
	 * @param string $orientation Orientation
	 * @return void
	 */
	public function setPaperSize($size = "A4", $orientation = "portrait")
	{
		$this->getDompdf()->set_paper($size, $orientation);
		return;
	}

	/**
	 * Sets the dompdf base path
	 * 
	 * @param string $path
	 * @return void
	 */
	public function setBasePath($path)
	{
		$this->getDompdf()->set_base_path($path);
	}

	/**
	 * Sets the html content
	 * 
	 * @param string $html Html Content
	 * @param string $encoding Encoding
	 * @return void
	 */
	public function setHtml($html, $encoding = null)
	{
		$this->getDompdf()->load_html($html, $encoding);
	}

	/**
	 * Streams pdf to the client
	 * 
	 * @param string $filename Filename 
	 * @param array $options Options
	 * @return void
	 */
	public function setStream($filename, $options = null)
	{
		$this->getDompdf()->stream($filename, $options);
	}

	/**
	 * Renders the pdf
	 */
	public function render()
	{
		$this->getDompdf()->render();
	}

	/**
	 * Sets a specific option to the pdf
	 * 
	 * @param string $option Option Key
	 * @param string $value Option Value
	 * @return Dompdf
	 */
	public function setOption($option, $value)
	{
		$this->getDompdf()->set_option($option, $value);
		return $this;
	}
	
}